==> haskell-openpgp-asciiarmor-0.1-25-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-openpgp-asciiarmor.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: openpgp-asciiarmor
version: 0.1
id: openpgp-asciiarmor-0.1-Ap0WOc44hcmKNmGzNSVPIB
key: openpgp-asciiarmor-0.1-Ap0WOc44hcmKNmGzNSVPIB
license: OtherLicense
copyright: 2012, Clint Adams
maintainer: Clint Adams <clint@debian.org>
homepage: http://floss.scru.org/openpgp-asciiarmor
synopsis: OpenPGP (RFC4880) ASCII Armor codec
description:
    OpenPGP (RFC4880) ASCII Armor codec
category: Codec, Data
author: Clint Adams
exposed: True
indefinite: False
exposed-modules:
    Codec.Encryption.OpenPGP.ASCIIArmor
    Codec.Encryption.OpenPGP.ASCIIArmor.Decode
    Codec.Encryption.OpenPGP.ASCIIArmor.Encode
    Codec.Encryption.OpenPGP.ASCIIArmor.Types
hidden-modules: Data.Digest.CRC24
                Codec.Encryption.OpenPGP.ASCIIArmor.Multipart
                Codec.Encryption.OpenPGP.ASCIIArmor.Utils
abi: 711843adb0790e6600e7408eafd2b693
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/openpgp-asciiarmor-0.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/openpgp-asciiarmor-0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/openpgp-asciiarmor-0.1
hs-libraries: HSopenpgp-asciiarmor-0.1-Ap0WOc44hcmKNmGzNSVPIB
depends:
    attoparsec-0.13.2.2-7ibVGq5lT2YZvA4JzOejy base-4.10.1.0
    base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be
    bytestring-0.10.8.2 cereal-0.5.4.0-HHG4trmDAey7tG5Rc3nyML
abi-depends: attoparsec-0.13.2.2-7ibVGq5lT2YZvA4JzOejy=9052f5e4288ee3b7fc66a1ba329f6d05
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be=fd5db0dc9688093c1ac2c3223371478e
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             cereal-0.5.4.0-HHG4trmDAey7tG5Rc3nyML=ed459ea038cbdb253abe2c011f65c556
haddock-interfaces: /usr/share/doc/haskell-openpgp-asciiarmor/html/openpgp-asciiarmor.haddock
haddock-html: /usr/share/doc/haskell-openpgp-asciiarmor/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-openpgp-asciiarmor-0.1-26-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-openpgp-asciiarmor.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: openpgp-asciiarmor
version: 0.1
id: openpgp-asciiarmor-0.1-H5Nw8Mf4fXrDcptKN9omBD
key: openpgp-asciiarmor-0.1-H5Nw8Mf4fXrDcptKN9omBD
license: OtherLicense
copyright: 2012, Clint Adams
maintainer: Clint Adams <clint@debian.org>
homepage: http://floss.scru.org/openpgp-asciiarmor
synopsis: OpenPGP (RFC4880) ASCII Armor codec
description:
    OpenPGP (RFC4880) ASCII Armor codec
category: Codec, Data
author: Clint Adams
exposed: True
indefinite: False
exposed-modules:
    Codec.Encryption.OpenPGP.ASCIIArmor
    Codec.Encryption.OpenPGP.ASCIIArmor.Decode
    Codec.Encryption.OpenPGP.ASCIIArmor.Encode
    Codec.Encryption.OpenPGP.ASCIIArmor.Types
hidden-modules: Data.Digest.CRC24
                Codec.Encryption.OpenPGP.ASCIIArmor.Multipart
                Codec.Encryption.OpenPGP.ASCIIArmor.Utils
abi: 25b1f031ccf708e6f866b2c94abcaff8
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/openpgp-asciiarmor-0.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/openpgp-asciiarmor-0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/openpgp-asciiarmor-0.1
hs-libraries: HSopenpgp-asciiarmor-0.1-H5Nw8Mf4fXrDcptKN9omBD
depends:
    attoparsec-0.13.2.2-1IsPw46SBaXMxKqrmF8MV base-4.10.1.0
    base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be
    bytestring-0.10.8.2 cereal-0.5.4.0-HHG4trmDAey7tG5Rc3nyML
abi-depends: attoparsec-0.13.2.2-1IsPw46SBaXMxKqrmF8MV=c494333baf54c0b8596ba018ce99c526
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be=fd5db0dc9688093c1ac2c3223371478e
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             cereal-0.5.4.0-HHG4trmDAey7tG5Rc3nyML=ed459ea038cbdb253abe2c011f65c556
haddock-interfaces: /usr/share/doc/haskell-openpgp-asciiarmor/html/openpgp-asciiarmor.haddock
haddock-html: /usr/share/doc/haskell-openpgp-asciiarmor/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
